@@ -8,7 +8,7 @@ Let's set up a site in which we manage a couple of objects::
 
   >>> herd = Herd()
   >>> getRootFolder()['herd'] = herd
-  >>> from zope.app.component.hooks import setSite
+  >>> from zope.site.hooks import setSite
   >>> setSite(herd)
 
 Now we add some indexable objects to the site::
@@ -18,7 +18,7 @@ Now we add some indexable objects to the site::
 
 We are able to query the catalog::
 
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> from zope.component import getUtility, queryUtility
   >>> catalog = getUtility(ICatalog)
   >>> for obj in catalog.searchResults(how_old=(13, 13)):
@@ -29,10 +29,10 @@ Nuke the catalog and intids in the end, so as not to confuse
 other tests::
 
   >>> sm = herd.getSiteManager()
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> sm.unregisterUtility(catalog, provided=ICatalog)
   True
-  >>> from zope.app.intid.interfaces import IIntIds
+  >>> from zope.intid.interfaces import IIntIds
   >>> from zope import component
   >>> intids = component.getUtility(IIntIds)
   >>> sm.unregisterUtility(intids, provided=IIntIds)
