@@ -6,7 +6,7 @@ Let's setup a site in which we manage a couple of objects:
 
   >>> herd = Herd()
   >>> getRootFolder()['herd'] = herd
-  >>> from zope.app.component.hooks import setSite
+  >>> from zope.site.hooks import setSite
   >>> setSite(herd)
 
 Now we add some indexable objects to the site:
@@ -16,22 +16,33 @@ Now we add some indexable objects to the site:
 
 Then we are able to query the catalog:
 
-  >>> from zope.app.catalog.interfaces import ICatalog
+  >>> from zope.catalog.interfaces import ICatalog
   >>> from zope.component import getUtility
   >>> catalog = getUtility(ICatalog)
   >>> for obj in catalog.searchResults(name=('Ellie', 'Ellie')):
   ...     print obj.name
   Ellie
 
+Nuke the catalog and intids in the end, so as not to confuse
+other tests::
+
+  >>> from zope import component
+  >>> sm = herd.getSiteManager()
+  >>> sm.unregisterUtility(catalog, provided=ICatalog)
+  True
+  >>> intids = component.getUtility(IIntIds)
+  >>> sm.unregisterUtility(intids, provided=IIntIds)
+  True
+
 """
 
 import grok
 from zope import schema, interface
-from zope.app.intid import IntIds
-from zope.app.intid.interfaces import IIntIds
-from zope.app.catalog.catalog import Catalog
-from zope.app.catalog.interfaces import ICatalog
-from zope.app.catalog.field import FieldIndex
+from zope.intid import IntIds
+from zope.intid.interfaces import IIntIds
+from zope.catalog.catalog import Catalog
+from zope.catalog.interfaces import ICatalog
+from zope.catalog.field import FieldIndex
 
 def setup_catalog(catalog):
     catalog['name'] = FieldIndex('name', IMammoth)
